@@ -9,17 +9,22 @@ my $mw = new MainWindow(
   -background => 'white',
 );
 my $GraphDummies = $mw->Lines(
-  -title      => 'My chart title',
+  -title      => 'bezier curve examples',
   -xlabel     => 'X Label',
   -ylabel     => 'Y Label',
   -background => 'snow',
-  -smoothline => 1,
+  -spline => 1,
+  -bezier => 1,
   -linewidth  => 2,
 )->pack(qw / -fill both -expand 1 /);
 
-my @data
-  = ( [ '1st', '2nd', '3rd' ], [ 10, 30, 10, ], [ 10, 0, 10, ], [ 20, 10, 30, ],
-  );
+my @data = (
+  [ '1st', '2nd', '3rd', '4th', '5th', '6th', '7th', '8th' ],
+  [ 10,    30,    20,    30,    5,     41,    1,     23 ],
+  [ 10,    5,     10,    0,     17,    2,     40,    23 ],
+  [ 20,    10,    12,    20,    30,    10,    35,    12 ],
+
+);
 
 # Add a legend to the chart
 my @Legends = ( 'legend 1', 'legend 2', 'legend 3' );
